@@ -1,5 +1,5 @@
 package Yancy::Plugin::Editor;
-our $VERSION = '1.029';
+our $VERSION = '1.030';
 # ABSTRACT: Yancy content editor, admin, and management application
 
 #pod =head1 SYNOPSIS
@@ -40,7 +40,58 @@ our $VERSION = '1.029';
 #pod
 #pod =head1 HELPERS
 #pod
-#pod XXX
+#pod =head2 yancy.editor.include
+#pod
+#pod     $app->yancy->editor->include( $template_name );
+#pod
+#pod Include a template in the editor, before the rest of the editor. Use this
+#pod to add your own L<Vue.JS|http://vuejs.org> components to the editor.
+#pod
+#pod =head2 yancy.editor.menu
+#pod
+#pod     $app->yancy->editor->menu( $category, $title, $config );
+#pod
+#pod Add a menu item to the editor. The C<$category> is the title of the category
+#pod in the sidebar. C<$title> is the title of the menu item. C<$config> is a
+#pod hash reference with the following keys:
+#pod
+#pod =over
+#pod
+#pod =item component
+#pod
+#pod The name of a Vue.JS component to display for this menu item. The
+#pod component will take up the entire main area of the application, and will
+#pod be kept active even after another menu item is selected.
+#pod
+#pod =back
+#pod
+#pod Yancy plugins should use the category C<Plugins>. Other categories are
+#pod available for custom applications.
+#pod
+#pod     app->yancy->editor->include( 'plugin/editor/custom_element' );
+#pod     app->yancy->editor->menu(
+#pod         'Plugins', 'Custom Item',
+#pod         {
+#pod             component => 'custom-element',
+#pod         },
+#pod     );
+#pod     __END__
+#pod     @@ plugin/editor/custom_element.html.ep
+#pod     <template id="custom-element-template">
+#pod         <div :id="'custom-element'">
+#pod             Hello, world!
+#pod         </div>
+#pod     </template>
+#pod     %= javascript begin
+#pod         Vue.component( 'custom-element', {
+#pod             template: '#custom-element-template',
+#pod         } );
+#pod     % end
+#pod
+#pod =for html
+#pod
+#pod <img alt="screenshot of yancy editor showing custom element"
+#pod     src="https://raw.github.com/preaction/Yancy/master/eg/doc-site/public/screenshot-custom-element.png?raw=true" />
 #pod
 #pod =head2 yancy.editor.route
 #pod
@@ -70,10 +121,12 @@ use Mojo::Base 'Mojolicious::Plugin';
 use Mojo::JSON qw( true false );
 use Mojo::Util qw( url_escape );
 use Sys::Hostname qw( hostname );
-use Yancy::Util qw( derp );
+use Yancy::Util qw( derp currym );
 
 has moniker => 'editor';
 has route =>;
+has includes => sub { [] };
+has menu_items => sub { +{} };
 
 sub _helper_name {
     my ( $self, $name ) = @_;
@@ -86,20 +139,13 @@ sub register {
     for my $key ( grep exists $config->{ $_ }, qw( moniker ) ) {
         $self->$key( $config->{ $key } );
     }
-
-    my $route = $config->{route} // $app->routes->any( '/yancy' );
-    $self->route( $route );
-    $route->to( return_to => $config->{return_to} // '/' );
     $config->{default_controller} //= $config->{api_controller} // 'Yancy';
     if ( $config->{api_controller} ) {
         derp 'api_controller configuration is deprecated. Use editor.default_controller instead';
     }
 
-    $app->helper( $self->_helper_name( 'route' ), sub { $route } );
-    $app->helper( 'yancy.route', sub {
-        derp 'yancy.route helper is deprecated. Use yancy.editor.route instead';
-        return $route;
-    } );
+    my $route = $config->{route} // $app->routes->any( '/yancy' );
+    $route->to( return_to => $config->{return_to} // '/' );
 
     # Create authentication for editor. We need to delay fetching this
     # callback until after startup is complete so that any auth plugin
@@ -126,6 +172,15 @@ sub register {
             action => 'index',
         );
 
+    $app->helper( $self->_helper_name( 'menu' ), currym( $self, '_helper_menu' ) );
+    $app->helper( $self->_helper_name( 'include' ), currym( $self, '_helper_include' ) );
+    $app->helper( $self->_helper_name( 'route' ), sub { $route } );
+    $app->helper( 'yancy.route', sub {
+        derp 'yancy.route helper is deprecated. Use yancy.editor.route instead';
+        return $self->route;
+    } );
+    $self->route( $route );
+
     my $spec;
     if ( $config->{openapi} && keys %{ $config->{openapi} } ) {
         $spec = $config->{openapi};
@@ -154,6 +209,25 @@ sub register {
     $formats->{ tel } = sub { undef };
 }
 
+sub _helper_include {
+    my ( $self, $c, @includes ) = @_;
+    if ( @includes ) {
+        push @{ $self->includes }, @includes;
+    }
+    return $self->includes;
+}
+
+sub _helper_menu {
+    my ( $self, $c, $category, $title, $config ) = @_;
+    if ( $config ) {
+        push @{ $self->menu_items->{ $category } }, {
+            %$config,
+            title => $title,
+        };
+    }
+    return $self->menu_items;
+}
+
 sub _openapi_find_schema_name {
     my ( $self, $path, $pathspec ) = @_;
     return $pathspec->{'x-schema'} if $pathspec->{'x-schema'};
@@ -492,7 +566,7 @@ Yancy::Plugin::Editor - Yancy content editor, admin, and management application
 
 =head1 VERSION
 
-version 1.029
+version 1.030
 
 =head1 SYNOPSIS
 
@@ -532,7 +606,63 @@ The URL to use for the "Back to Application" link. Defaults to C</>.
 
 =head1 HELPERS
 
-XXX
+=head2 yancy.editor.include
+
+    $app->yancy->editor->include( $template_name );
+
+Include a template in the editor, before the rest of the editor. Use this
+to add your own L<Vue.JS|http://vuejs.org> components to the editor.
+
+=head2 yancy.editor.menu
+
+    $app->yancy->editor->menu( $category, $title, $config );
+
+Add a menu item to the editor. The C<$category> is the title of the category
+in the sidebar. C<$title> is the title of the menu item. C<$config> is a
+hash reference with the following keys:
+
+=over
+
+=item component
+
+The name of a Vue.JS component to display for this menu item. The
+component will take up the entire main area of the application, and will
+be kept active even after another menu item is selected.
+
+=back
+
+Yancy plugins should use the category C<Plugins>. Other categories are
+available for custom applications.
+
+    app->yancy->editor->include( 'plugin/editor/custom_element' );
+    app->yancy->editor->menu(
+        'Plugins', 'Custom Item',
+        {
+            component => 'custom-element',
+        },
+    );
+    __END__
+    @@ plugin/editor/custom_element.html.ep
+    <template id="custom-element-template">
+        <div :id="'custom-element'">
+            Hello, world!
+        </div>
+    </template>
+    %= javascript begin
+        Vue.component( 'custom-element', {
+            template: '#custom-element-template',
+        } );
+    % end
+
+=begin html
+
+
+
+
+=end html
+
+<img alt="screenshot of yancy editor showing custom element"
+    src="https://raw.github.com/preaction/Yancy/master/eg/doc-site/public/screenshot-custom-element.png?raw=true" />
 
 =head2 yancy.editor.route
 
